@@ -67,7 +67,7 @@ class Check(Action):
 
     def __init__(self, status, command, ref, t_to_go, dep_check=None, id=None,
                  timeout=10, poller_tag='None', reactionner_tag='None',
-                 env={}, module_type='fork', from_trigger=False):
+                 env={}, module_type='fork', from_trigger=False, dependency_check=False):
 
         self.is_a = 'check'
         self.type = ''
@@ -107,6 +107,8 @@ class Check(Action):
         else:
             self.internal = False
         self.from_trigger = from_trigger
+        self.dependency_check = dependency_check
+
 
     def copy_shell(self):
         """return a copy of the check but just what is important for execution
@@ -139,3 +141,6 @@ class Check(Action):
 
     def set_type_passive(self):
         self.check_type = 1
+
+    def is_dependent(self):
+        return self.dependency_check
