@@ -519,6 +519,7 @@ class Config(Item):
         tmp = []
         tmp_type = 'void'
         in_define = False
+        almost_in_define=False
         continuation_line = False
         tmp_line = ''
         lines = buf.split('\n')
@@ -548,12 +549,22 @@ class Config(Item):
             if re.search("^\s*}\s*$", line) is not None:
                 in_define = False
 
+            # { alone in a line can mean start object reading
+            if re.search("^\s*{\s*$", line) is not None and almost_in_define:
+                almost_in_define=False
+                in_define = True
+                continue
+
             if re.search("^\s*#|^\s*$|^\s*}", line) is not None:
                 pass
             # A define must be catch and the type save
             # The old entry must be save before
             elif re.search("^define", line) is not None:
-                in_define = True
+                if re.search(".*{.*$", line) is not None:
+                    in_define = True
+                else:
+                    almost_in_define=True
+
                 if tmp_type not in objectscfg:
                     objectscfg[tmp_type] = []
                 objectscfg[tmp_type].append(tmp)
@@ -1345,6 +1356,7 @@ class Config(Item):
                   'hostsextinfo', 'servicesextinfo', 'checkmodulations', 'macromodulations'):
             if self.read_config_silent == 0:
                 logger.info('Checking %s...' % (x))
+
             cur = getattr(self, x)
             if not cur.is_correct():
                 r = False
@@ -1400,11 +1412,11 @@ class Config(Item):
                 self.add_error("Error: hosts exist with poller_tag %s but no poller got this tag" % tag)
                 r = False
         if not services_tag.issubset(pollers_tag):
-            for tag in services_tag.difference(pollers_tag):        
+            for tag in services_tag.difference(pollers_tag):
                 logger.error("Services exist with poller_tag %s but no poller got this tag" % tag)
                 self.add_error("Error: services exist with poller_tag %s but no poller got this tag" % tag)
                 r = False
-    
+
 
         # Check that all hosts involved in business_rules are from the same realm
         for l in [self.services, self.hosts]:
